@@ -4,6 +4,6 @@ from policyengine_us.model_api import *
 class age(Variable):
     value_type = float
     entity = Person
-    label = "Age"
+    label = "age"
     definition_period = YEAR
     default_value = 40
